@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2002 - 2004 Christian Kreibich
+Copyright (C) 2002 - 2007 Christian Kreibich
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
@@ -25,10 +25,6 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #ifndef __pcapnav_append_h
 #define __pcapnav_append_h
 
-#if HAVE_CONFIG_H
-# include <config.h>
-#endif
-
 #include "pcapnav.h"
 
 pcap_dumper_t *   pcapnav_append_fast(pcap_t *pcap, const char *filename);
