@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2002 - 2004 Christian Kreibich
+Copyright (C) 2002 - 2007 Christian Kreibich
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
@@ -22,6 +22,10 @@ IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 */
+#if HAVE_CONFIG_H
+# include <config.h>
+#endif
+
 #include <pcapnav.h>
 
 struct pcapnav_runtime_options pcapnav_runtime_options;
