@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2002 - 2004 Christian Kreibich
+Copyright (C) 2002 - 2007 Christian Kreibich
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
@@ -25,6 +25,6 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #ifndef __pcapnav_timestamp_h
 #define __pcapnav_timestamp_h
 
-#define PCAPNAV_LAST_UPDATE "Wed May  4 18:19:44 BST 2005"
+#define PCAPNAV_LAST_UPDATE "Mon Jun  4 18:40:36 PDT 2007"
 
 #endif
